pub enum Expression {
Binary(Binary, Box<Expression>, Box<Expression>),
Constant(u32),
Die(Die, Option<Reroll>),
Dice(Dice, Option<Reroll>, Fold),
}Expand description
A dice rolling expression.
Variants
Binary(Binary, Box<Expression>, Box<Expression>)
A binary expression.
Constant(u32)
A constant expression.
Die(Die, Option<Reroll>)
A die expression.
Dice(Dice, Option<Reroll>, Fold)
A dice expression.
Implementations
Sourceimpl Expression
impl Expression
Sourcepub fn minimum(&self) -> Option<i32>
pub fn minimum(&self) -> Option<i32>
Returns the smallest possible result of rolling this dice rolling expression.
Sourcepub fn maximum(&self) -> Option<i32>
pub fn maximum(&self) -> Option<i32>
Returns the largest possible result of rolling this dice rolling expression.
Sourcepub fn average(&self) -> Option<Ratio>
pub fn average(&self) -> Option<Ratio>
Returns the average result of rolling this dice rolling expression.